Transport

Struct Transport 

pub struct Transport<I, Name> {
    pub config: TransportConfig,
    /* private fields */
}
Transport for data betweeen client and server, generic over the rpc names and internal transport The majority of the heavy lifting is done by the [internal_transport], see the definition of the InternalTransport trait for more information

Fields

config: TransportConfig

Implementations

Source

impl<I: InternalTransport, Name: RpcName> Transport<I, Name>

pub fn new(internal_transport: I, transport_config: TransportConfig) -> Self

pub async fn send_query( &mut self, query_bytes: Bytes<'_>, rpc_name: &Name, ) -> RpcResult<OwnedBytes>

pub async fn receive_query(&mut self) -> RpcResult<ReceivedQuery<Name>>

pub async fn respond(&mut self, bytes: Bytes<'_>) -> RpcResult<()>